@@ -1,10 +1,14 @@
 try:
-    from streamlit.script_run_context import get_script_run_ctx
+    from streamlit.scriptrunner import get_script_run_ctx
 except ModuleNotFoundError:
-    # streamlit < 1.4
-    from streamlit.report_thread import (  # type: ignore
-        get_report_ctx as get_script_run_ctx,
-    )
+    # streamlit < 1.8
+    try:
+        from streamlit.script_run_context import get_script_run_ctx  # type: ignore
+    except ModuleNotFoundError:
+        # streamlit < 1.4
+        from streamlit.report_thread import (  # type: ignore
+            get_report_ctx as get_script_run_ctx,
+        )
 
 from streamlit.server.server import Server
 
